@@ -1,4 +1,6 @@
-/* Copyright(C) 2011 Kentoku SHIBA
+/*
+  Copyright(C) 2011 Kentoku SHIBA
+  Copyright(C) 2014-2017 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -28,5 +30,20 @@
 #define ER_MRN_ERROR_FROM_GROONGA_STR "Error from Groonga [%s]"
 #define ER_MRN_INVALID_NULL_VALUE_NUM 16505
 #define ER_MRN_INVALID_NULL_VALUE_STR "NULL value can't be used for %s"
+#define ER_MRN_UNSUPPORTED_COLUMN_FLAG_NUM 16506
+#define ER_MRN_UNSUPPORTED_COLUMN_FLAG_STR \
+  "The column flag '%-.64s' is unsupported. It is ignored"
+#define ER_MRN_INVALID_COLUMN_FLAG_NUM 16507
+#define ER_MRN_INVALID_COLUMN_FLAG_STR \
+  "The column flag '%-.64s' is invalid. It is ignored"
+#define ER_MRN_INVALID_INDEX_FLAG_NUM 16508
+#define ER_MRN_INVALID_INDEX_FLAG_STR \
+  "The index flag '%-.64s' is invalid. It is ignored"
+#define ER_MRN_KEY_BASED_ON_GENERATED_VIRTUAL_COLUMN_NUM 16509
+#define ER_MRN_KEY_BASED_ON_GENERATED_VIRTUAL_COLUMN_STR \
+  "Index for virtual generated column is not supported: %s"
+#define ER_MRN_INVALID_TABLE_FLAG_NUM 16510
+#define ER_MRN_INVALID_TABLE_FLAG_STR \
+  "The table flag '%-.64s' is invalid. It is ignored"
 
 #endif /* MRN_ERR_H_ */
